InvocationContext

Struct InvocationContext 

pub struct InvocationContext {
    pub return_address: NativePointer,
    pub context: CpuContext,
    pub thread_id: u32,
    pub depth: u32,
    /* private fields */
}
Per-invocation object that contains useful properties about the program at the point of interception.

This is equivalent to the this object accessible in the Interceptor callback in the JavaScript API.

The get and set methods can be used to store arbitrary Rust objects that will be accessible at any point during the invocation. For example, this could be used to store values during on_enter that can later be retrieved during on_leave.

Fields

return_address: NativePointer

Return address of the intercepted function.

context: CpuContext

Current CPU context.

thread_id: u32

OS thread ID.

depth: u32

Call depth relative to other invocations.

Implementations

Source

impl InvocationContext

pub fn get<T>(&self, prop: &str) -> T
where T: for<'a> Deserialize<'a>,

Get the value stored with the prop key.

pub fn set<T>(&self, prop: &str, val: &T)
where T: Serialize + ?Sized,

Stores val within the context with the prop key. val can be any serializable Rust object.