pub struct InvocationContext {
pub return_address: NativePointer,
pub context: CpuContext,
pub thread_id: u32,
pub depth: u32,
/* private fields */
}Expand description
Per-invocation object that contains useful properties about the program at the point of interception.
This is equivalent to the this object accessible in the Interceptor
callback in the JavaScript API.
The get and set methods can be used to store arbitrary
Rust objects that will be accessible at any point during the invocation.
For example, this could be used to store values during on_enter that can
later be retrieved during on_leave.
Fields
return_address: NativePointerReturn address of the intercepted function.
context: CpuContextCurrent CPU context.
thread_id: u32OS thread ID.
depth: u32Call depth relative to other invocations.
Implementations